@@ -17,6 +17,7 @@ import (
 	"github.com/spf13/cobra/doc"
 	"github.com/ubuntu/adsys/cmd/adsysd/client"
 	"github.com/ubuntu/adsys/cmd/adsysd/daemon"
+	"github.com/ubuntu/adsys/cmd/adwatchd/commands"
 	"github.com/ubuntu/adsys/internal/generators"
 )
 
@@ -39,8 +40,9 @@ func main() {
 
 	c := client.New()
 	d := daemon.New()
+	w := commands.New()
 
-	commands := []cobra.Command{c.RootCmd(), d.RootCmd()}
+	commands := []cobra.Command{c.RootCmd(), d.RootCmd(), w.RootCmd()}
 	switch os.Args[1] {
 	case "completion":
 		if len(os.Args) < 3 {
@@ -63,7 +65,7 @@ func main() {
 		if generators.InstallOnlyMode() {
 			return
 		}
-		updateFromCmd(commands, filepath.Join("doc", "11.-Command-line-reference.md"))
+		updateFromCmd(commands, filepath.Join("doc", "15.-Command-line-reference.md"))
 	default:
 		log.Fatalf(usage, os.Args[0])
 	}
@@ -77,7 +79,7 @@ func genCompletions(cmds []cobra.Command, dir string) {
 		if err := generators.CleanDirectory(filepath.Dir(d)); err != nil {
 			log.Fatalln(err)
 		}
-		if err := os.MkdirAll(d, 0755); err != nil {
+		if err := generators.CreateDirectory(d, 0755); err != nil {
 			log.Fatalf("Couldn't create bash completion directory: %v", err)
 		}
 	}
@@ -99,7 +101,7 @@ func genManPages(cmds []cobra.Command, dir string) {
 	}
 
 	out := filepath.Join(manBaseDir, "man1")
-	if err := os.MkdirAll(out, 0755); err != nil {
+	if err := generators.CreateDirectory(out, 0755); err != nil {
 		log.Fatalf("Couldn't create man pages directory: %v", err)
 	}
 
