@@ -3,15 +3,14 @@ package adsysservice
 import (
 	"context"
 	"fmt"
-	"os"
 
 	"github.com/ubuntu/adsys"
+	"github.com/ubuntu/adsys/internal/ad"
 	"github.com/ubuntu/adsys/internal/adsysservice/actions"
 	"github.com/ubuntu/adsys/internal/authorizer"
-	"github.com/ubuntu/adsys/internal/decorate"
 	log "github.com/ubuntu/adsys/internal/grpc/logstreamer"
 	"github.com/ubuntu/adsys/internal/i18n"
-	"github.com/ubuntu/adsys/internal/policies/ad"
+	"github.com/ubuntu/decorate"
 	"golang.org/x/sync/errgroup"
 )
 
@@ -40,10 +39,8 @@ func (s *Service) UpdatePolicy(r *adsys.UpdatePolicyRequest, stream adsys.Servic
 	}
 
 	if r.GetIsComputer() || r.GetAll() {
-		hostname, err := os.Hostname()
-		if err != nil {
-			return err
-		}
+		hostname := s.adc.Hostname()
+
 		err = s.updatePolicyFor(stream.Context(), true, hostname, ad.ComputerObject, "")
 
 		if r.GetAll() {
@@ -59,7 +56,7 @@ func (s *Service) UpdatePolicy(r *adsys.UpdatePolicyRequest, stream adsys.Servic
 				})
 			}
 			if err := errg.Wait(); err != nil {
-				return fmt.Errorf("one or more error for updating all users: %v", err)
+				return fmt.Errorf("one or more error for updating all users: %w", err)
 			}
 		}
 
@@ -69,39 +66,39 @@ func (s *Service) UpdatePolicy(r *adsys.UpdatePolicyRequest, stream adsys.Servic
 	return s.updatePolicyFor(stream.Context(), r.GetIsComputer(), target, objectClass, r.Krb5Cc)
 }
 
-// updatePolicyFor updates the policy for a given object
+// updatePolicyFor updates the policy for a given object.
 func (s *Service) updatePolicyFor(ctx context.Context, isComputer bool, target string, objectClass ad.ObjectClass, krb5cc string) error {
-	gpos, err := s.adc.GetPolicies(ctx, target, objectClass, krb5cc)
+	pols, err := s.adc.GetPolicies(ctx, target, objectClass, krb5cc)
 	if err != nil {
 		return err
 	}
 
-	return s.policyManager.ApplyPolicy(ctx, target, isComputer, gpos)
-
+	return s.policyManager.ApplyPolicies(ctx, target, isComputer, &pols)
 }
 
 // DumpPolicies displays all applied policies for a given user.
 func (s *Service) DumpPolicies(r *adsys.DumpPoliciesRequest, stream adsys.Service_DumpPoliciesServer) (err error) {
 	defer decorate.OnError(&err, i18n.G("error while displaying applied policies"))
 
-	target, err := s.adc.NormalizeTargetName(stream.Context(), r.GetTarget(), "")
+	objectClass := ad.UserObject
+	if r.GetIsComputer() {
+		objectClass = ad.ComputerObject
+	}
+
+	target, err := s.adc.NormalizeTargetName(stream.Context(), r.GetTarget(), objectClass)
 	if err != nil {
 		return err
 	}
 
 	// hostname policy display is allowed to all users
-	hostname, err := os.Hostname()
-	if err != nil {
-		return err
-	}
-	if target != hostname {
+	if target != s.adc.Hostname() {
 		if err := s.authorizer.IsAllowedFromContext(context.WithValue(stream.Context(), authorizer.OnUserKey, target),
 			actions.ActionPolicyDump); err != nil {
 			return err
 		}
 	}
 
-	msg, err := s.policyManager.DumpPolicies(stream.Context(), target, r.GetDetails(), r.GetAll())
+	msg, err := s.policyManager.DumpPolicies(stream.Context(), target, r.GetIsComputer(), r.GetDetails(), r.GetAll())
 	if err != nil {
 		return err
 	}
@@ -138,7 +135,7 @@ func (s *Service) DumpPoliciesDefinitions(r *adsys.DumpPolicyDefinitionsRequest,
 }
 
 // GPOListScript returns the embedded GPO python list script.
-func (s *Service) GPOListScript(r *adsys.Empty, stream adsys.Service_GPOListScriptServer) (err error) {
+func (s *Service) GPOListScript(_ *adsys.Empty, stream adsys.Service_GPOListScriptServer) (err error) {
 	defer decorate.OnError(&err, i18n.G("error while getting gpo list script"))
 
 	if err := s.authorizer.IsAllowedFromContext(stream.Context(), authorizer.ActionAlwaysAllowed); err != nil {
