@@ -4,13 +4,13 @@ import (
 	"github.com/ubuntu/adsys"
 	"github.com/ubuntu/adsys/internal/authorizer"
 	"github.com/ubuntu/adsys/internal/consts"
-	"github.com/ubuntu/adsys/internal/decorate"
 	log "github.com/ubuntu/adsys/internal/grpc/logstreamer"
 	"github.com/ubuntu/adsys/internal/i18n"
+	"github.com/ubuntu/decorate"
 )
 
 // Version returns version from server.
-func (s *Service) Version(r *adsys.Empty, stream adsys.Service_VersionServer) (err error) {
+func (s *Service) Version(_ *adsys.Empty, stream adsys.Service_VersionServer) (err error) {
 	defer decorate.OnError(&err, i18n.G("error while getting daemon version"))
 
 	if err := s.authorizer.IsAllowedFromContext(stream.Context(), authorizer.ActionAlwaysAllowed); err != nil {
