@@ -18,7 +18,6 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	"github.com/ubuntu/adsys/internal/config"
-	"github.com/ubuntu/adsys/internal/testutils"
 )
 
 func TestSetVerboseMode(t *testing.T) {
@@ -86,14 +85,20 @@ func TestSetVerboseMode(t *testing.T) {
 
 func TestInit(t *testing.T) {
 	tests := map[string]struct {
-		withValueFlagSet  bool
-		noVerboseFlag     bool
-		noConfigFlag      bool
-		withConfigFlagSet string
-		withConfigEnv     bool
-		configFileContent string
-		notInConfigDir    bool
-		changeConfigWith  string
+		withValueFlagSet   bool
+		noVerboseFlag      bool
+		noConfigFlag       bool
+		withConfigFlagSet  string
+		withConfigEnv      bool
+		withConfigInExeDir bool
+		configFileContent  string
+		notInConfigDir     bool
+		changeConfigWith   string
+
+		directlyChangeConfigFile bool
+
+		subcommand             bool
+		configFlagOnSubcommand bool
 
 		errFromCallbackOn int
 
@@ -108,6 +113,12 @@ func TestInit(t *testing.T) {
 			configFileContent: "value: filecontentvalue",
 			want:              "filecontentvalue", wantCallbackCalled: 1,
 		},
+		"Load configuration from executable dir": {
+			configFileContent:  "value: filecontentvalue",
+			withConfigInExeDir: true,
+			notInConfigDir:     true,
+			want:               "filecontentvalue", wantCallbackCalled: 1,
+		},
 		"No config flag set before Init is call is ignored": {
 			noConfigFlag:       true,
 			wantCallbackCalled: 1,
@@ -122,6 +133,14 @@ func TestInit(t *testing.T) {
 			withConfigFlagSet: "custom.yaml", notInConfigDir: true,
 			want: "customconfigvalue", wantCallbackCalled: 1,
 		},
+		"Configuration flag on parent, not in config dir, init on subcommand": {
+			withConfigFlagSet: "custom.yaml", notInConfigDir: true, subcommand: true,
+			want: "customconfigvalue", wantCallbackCalled: 1,
+		},
+		"Configuration flag on subcommand, not in config dir, init on subcommand": {
+			withConfigFlagSet: "custom.yaml", notInConfigDir: true, subcommand: true, configFlagOnSubcommand: true,
+			want: "customconfigvalue", wantCallbackCalled: 1,
+		},
 		"Flag is supported": {
 			withValueFlagSet: true,
 			want:             "flagvalue", wantCallbackCalled: 1},
@@ -131,8 +150,12 @@ func TestInit(t *testing.T) {
 		},
 
 		// Configuration changes support
-		"Configuration changed": {
-			configFileContent: "value: filecontentvalue", changeConfigWith: "value: filecontentvaluerefreshed",
+		"Configuration changed directly": {
+			configFileContent: "value: filecontentvalue", changeConfigWith: "value: filecontentvaluerefreshed", directlyChangeConfigFile: true,
+			want: "filecontentvaluerefreshed", wantCallbackCalled: 2,
+		},
+		"Configuration file overwritten": {
+			configFileContent: "value: filecontentvalue", changeConfigWith: "value: filecontentvaluerefreshed", directlyChangeConfigFile: false,
 			want: "filecontentvaluerefreshed", wantCallbackCalled: 2,
 		},
 		"Configuration file created after Init() is not taken into account": {
@@ -170,28 +193,53 @@ func TestInit(t *testing.T) {
 		tc := tc
 		t.Run(name, func(t *testing.T) {
 			configDir := t.TempDir()
+			prefix := "adsys_config_test"
+
+			if tc.withConfigInExeDir {
+				exePath, err := os.Executable()
+				require.NoError(t, err, "Setup: can't get executable path")
+				configDir = filepath.Dir(exePath)
+
+				t.Cleanup(func() {
+					os.Remove(filepath.Join(configDir, prefix+".yaml"))
+					syscall.Sync()
+				})
+			}
+
 			if !tc.notInConfigDir {
 				chDir(t, configDir)
 			}
 
 			// Setup config to read
 			vip := viper.New()
-			cmd := cobra.Command{}
-			cmd.PersistentFlags().String("value", "", "value flag")
-			err := vip.BindPFlag("value", cmd.PersistentFlags().Lookup("value"))
+			rootCmd := cobra.Command{}
+			rootCmd.PersistentFlags().String("value", "", "value flag")
+			err := vip.BindPFlag("value", rootCmd.PersistentFlags().Lookup("value"))
 			require.NoError(t, err, "Setup: can't bind value flag to viper")
 
 			if tc.withValueFlagSet {
-				err := cmd.PersistentFlags().Set("value", "flagvalue")
+				err := rootCmd.PersistentFlags().Set("value", "flagvalue")
 				require.NoError(t, err, "Setup: can’t set value flag")
 			}
 
 			if !tc.noVerboseFlag {
-				cmd.PersistentFlags().CountP("verbose", "v", "verbose flag")
+				rootCmd.PersistentFlags().CountP("verbose", "v", "verbose flag")
 			}
 
-			if !tc.noConfigFlag {
-				cmd.PersistentFlags().String("config", "", "config flag")
+			if !tc.noConfigFlag && !tc.configFlagOnSubcommand {
+				rootCmd.PersistentFlags().String("config", "", "config flag")
+			}
+
+			cmdFlags := rootCmd.PersistentFlags()
+			cmd := rootCmd
+			if tc.subcommand {
+				subcmd := cobra.Command{}
+				if tc.configFlagOnSubcommand {
+					cmdFlags = subcmd.Flags()
+					cmdFlags.String("config", "", "config flag")
+				}
+				rootCmd.AddCommand(&subcmd)
+				cmd = subcmd
 			}
 
 			if tc.withConfigFlagSet != "" {
@@ -200,13 +248,12 @@ func TestInit(t *testing.T) {
 					err = os.WriteFile(p, []byte("value: customconfigvalue"), 0600)
 					require.NoError(t, err, "Setup: failed to write custom config file")
 				}
-				err := cmd.PersistentFlags().Set("config", p)
+				err := cmdFlags.Set("config", p)
 				require.NoError(t, err, "Setup: can’t set config flag")
 			}
 
-			prefix := "adsys_config_test"
 			if tc.withConfigEnv {
-				testutils.Setenv(t, strings.ToUpper(prefix)+"_VALUE", "envvalue")
+				t.Setenv(strings.ToUpper(prefix)+"_VALUE", "envvalue")
 			}
 
 			if tc.configFileContent != "" {
@@ -270,8 +317,23 @@ func TestInit(t *testing.T) {
 				callbackPhase = 2
 				phaseMu.Unlock()
 
-				err = os.WriteFile(filepath.Join(configDir, prefix+".yaml"), []byte(tc.changeConfigWith), 0600)
-				require.NoError(t, err, "Setup: failed to write initial config file")
+				if tc.directlyChangeConfigFile {
+					// fsnotify docs states that truncating a file will also trigger a Write event, which means that the callback can be triggered
+					// before the file contents are properly written. In order to avoid that, we must manually open the file and write the new content
+					// to it to avoid truncating the file and triggering the event too early.
+					configFile, err := os.OpenFile(filepath.Join(configDir, prefix+".yaml"), os.O_RDWR|os.O_CREATE, os.ModePerm)
+					require.NoError(t, err, "Setup: failed to open config file")
+					defer configFile.Close()
+					_, err = configFile.WriteString(tc.changeConfigWith)
+					require.NoError(t, err, "Setup: failed to write new content to config file")
+					configFile.Close()
+				} else {
+					err := os.WriteFile(filepath.Join(configDir, prefix+".new"), []byte(tc.changeConfigWith), 0600)
+					require.NoError(t, err, "Setup: failed to write .new config file")
+					err = os.Rename(filepath.Join(configDir, prefix+".new"), filepath.Join(configDir, prefix+".yaml"))
+					require.NoError(t, err, "Setup: failed to rename .new file to the expected name")
+				}
+
 				// Let’s force a sync to make sure the file is written on disk
 				syscall.Sync()
 				select {
