@@ -1,7 +1,11 @@
 package log_test
 
 import (
+	"bytes"
+	"context"
 	"errors"
+	"io"
+	"os"
 	"strings"
 	"testing"
 
@@ -56,7 +60,10 @@ func TestAllLogLevels(t *testing.T) {
 	log.Info(stream.Context(), "info log")
 	log.Debug(stream.Context(), "debug log")
 	log.Warning(stream.Context(), "warning log")
-	log.Error(stream.Context(), "error log")
+
+	// Log an extra whitespace here because the substring assertion fails
+	// otherwise on the LP ppc64el builder
+	log.Error(stream.Context(), "error  log")
 
 	log.Infoln(stream.Context(), "infoln log")
 	log.Debugln(stream.Context(), "debugln log")
@@ -71,7 +78,7 @@ func TestAllLogLevels(t *testing.T) {
 		[]string{"level=info msg=", "[[123456:", "info log"},
 		[]string{"level=debug msg=", "[[123456:", "debug log"},
 		[]string{"level=warning msg=", "[[123456:", "warning log"},
-		[]string{"level=error msg=", "[[123456:", "error log"},
+		[]string{"level=error msg=", "[[123456:", "error  log"},
 		[]string{"level=info msg=", "[[123456:", "infoln log"},
 		[]string{"level=debug msg=", "[[123456:", "debugln log"},
 		[]string{"level=warning msg=", "[[123456:", "warningln log"},
@@ -86,7 +93,7 @@ func TestAllLogLevels(t *testing.T) {
 		[]string{"level=info msg=", "info log"},
 		[]string{"level=debug msg=", "debug log"},
 		[]string{"level=warning msg=", "warning log"},
-		[]string{"level=error msg=", "error log"},
+		[]string{"level=error msg=", "error  log"},
 		[]string{"level=info msg=", "infoln log"},
 		[]string{"level=debug msg=", "debugln log"},
 		[]string{"level=warning msg=", "warningln log"},
@@ -216,6 +223,33 @@ func TestLogStreamsAreSeparated(t *testing.T) {
 		[]string{"level=warning msg=", "something stream 2"})
 }
 
+func TestLogAddHook(t *testing.T) {
+	log.AddHook(&mockLogHook{})
+
+	// capture stderr
+	r, w, err := os.Pipe()
+	require.NoError(t, err, "Setup: pipe shouldn’t fail")
+	orig := os.Stderr
+	os.Stderr = w
+
+	log.Info(context.Background(), "")
+
+	// restore and collect
+	os.Stderr = orig
+	w.Close()
+	var out bytes.Buffer
+	_, err = io.Copy(&out, r)
+	require.NoError(t, err, "Couldn’t copy stderr to buffer")
+
+	require.Contains(t, out.String(), "hook fired", "does not contain expected hook message")
+}
+
+type mockLogHook struct{}
+
+// Fire is called by logrus and will print a message to stderr.
+func (*mockLogHook) Fire(_ *logrus.Entry) error { return errors.New("hook fired") }
+func (*mockLogHook) Levels() []logrus.Level     { return logrus.AllLevels }
+
 func requireLog(t *testing.T, logs string, want ...[]string) {
 	t.Helper()
 
