@@ -1,3 +1,6 @@
+// Package testutils contains several helpers and assertions for our unit, package or integration tests.
+//
+// This package is not embed in the finale binary.
 package testutils
 
 import (
@@ -14,6 +17,43 @@ import (
 	"github.com/termie/go-shutil"
 )
 
+// Chdir changes current directory to dir.
+// The previous current directory is restored when the test ends.
+func Chdir(t *testing.T, dir string) {
+	t.Helper()
+
+	orig, err := os.Getwd()
+	if err != nil {
+		t.Fatalf("Setup: Can’t get current directory: %v", err)
+	}
+	if err := os.Chdir(dir); err != nil {
+		t.Fatalf("Setup: Can’t change current directory: %v", err)
+	}
+	t.Cleanup(func() {
+		if err := os.Chdir(orig); err != nil {
+			t.Fatalf("Teardown: Can’t restore current directory: %v", err)
+		}
+	})
+}
+
+// CreatePath creates a directory or a file with dummy content based on whether
+// the given path contains a slash character at the end.
+func CreatePath(t *testing.T, path string) {
+	t.Helper()
+
+	if strings.HasSuffix(path, "/") {
+		err := os.MkdirAll(path, 0750)
+		require.NoError(t, err, "Setup: cannot create directory %s", path)
+		return
+	}
+
+	err := os.MkdirAll(filepath.Dir(path), 0750)
+	require.NoError(t, err, "Setup: can't create directory for file")
+
+	err = os.WriteFile(path, []byte("new content"), 0600)
+	require.NoError(t, err, "Setup: could not write sample file")
+}
+
 // Copy copies files and directories to dest.
 func Copy(t *testing.T, src, dest string) {
 	t.Helper()
@@ -44,11 +84,20 @@ func MakeReadOnly(t *testing.T, dest string) {
 	require.NoError(t, err, "Cannot stat %s", dest)
 	mode := fi.Mode()
 
-	err = os.Chmod(dest, 0444)
+	var perms fs.FileMode = 0444
+	if fi.IsDir() {
+		perms = 0555
+	}
+	err = os.Chmod(dest, perms)
 	require.NoError(t, err)
 
 	t.Cleanup(func() {
-		err := os.Chmod(dest, mode)
+		_, err := os.Stat(dest)
+		if errors.Is(err, os.ErrNotExist) {
+			return
+		}
+
+		err = os.Chmod(dest, mode)
 		require.NoError(t, err)
 	})
 }
@@ -89,17 +138,17 @@ func CompareTreesWithFiltering(t *testing.T, p, goldPath string, update bool) {
 	}
 
 	var err error
-	var gotContent map[string]string
+	var gotContent map[string]treeAttrs
 	if _, err := os.Stat(p); err == nil {
-		gotContent, err = treeContent(t, p, []byte("GVariant"))
+		gotContent, err = treeContentAndAttrs(t, p, []byte("GVariant"))
 		if err != nil {
 			t.Fatalf("No generated content: %v", err)
 		}
 	}
 
-	var goldContent map[string]string
+	var goldContent map[string]treeAttrs
 	if _, err := os.Stat(goldPath); err == nil {
-		goldContent, err = treeContent(t, goldPath, nil)
+		goldContent, err = treeContentAndAttrs(t, goldPath, nil)
 		if err != nil {
 			t.Fatalf("No golden directory found: %v", err)
 		}
@@ -166,12 +215,19 @@ func addEmptyMarker(p string) error {
 	return err
 }
 
-// treeContent builds a recursive file list of dir with their content
+// treeAttrs are the attributes to take into consideration when comparing each file.
+type treeAttrs struct {
+	content    string
+	path       string
+	executable bool
+}
+
+// treeContentAndAttrs builds a recursive file list of dir with their content and other attributes.
 // It can ignore files starting with ignoreHeaders.
-func treeContent(t *testing.T, dir string, ignoreHeaders []byte) (map[string]string, error) {
+func treeContentAndAttrs(t *testing.T, dir string, ignoreHeaders []byte) (map[string]treeAttrs, error) {
 	t.Helper()
 
-	r := make(map[string]string)
+	r := make(map[string]treeAttrs)
 
 	err := filepath.WalkDir(dir, func(path string, de fs.DirEntry, err error) error {
 		if err != nil {
@@ -184,6 +240,8 @@ func treeContent(t *testing.T, dir string, ignoreHeaders []byte) (map[string]str
 		}
 
 		content := ""
+		info, err := os.Stat(path)
+		require.NoError(t, err, "Cannot stat %s", path)
 		if !de.IsDir() {
 			d, err := os.ReadFile(path)
 			if err != nil {
@@ -195,7 +253,8 @@ func treeContent(t *testing.T, dir string, ignoreHeaders []byte) (map[string]str
 			}
 			content = string(d)
 		}
-		r[strings.TrimPrefix(path, dir)] = content
+		trimmedPath := strings.TrimPrefix(path, dir)
+		r[trimmedPath] = treeAttrs{content, strings.TrimPrefix(path, dir), info.Mode()&0111 != 0}
 		return nil
 	})
 	if err != nil {
@@ -223,3 +282,15 @@ func ignoreDconfDB(src string, entries []os.FileInfo) []string {
 	}
 	return r
 }
+
+// markForTestCache list all root directories/files so that they are marked in the test cache.
+func markForTestCache(t *testing.T, roots []string) {
+	t.Helper()
+
+	for _, root := range roots {
+		err := filepath.WalkDir(root, func(path string, d os.DirEntry, err error) error {
+			return nil
+		})
+		require.NoError(t, err, "Setup: Error when listing input files for caching handling")
+	}
+}
